﻿//---=== modPotionsSorting ===---
function SortInventoryFlashArray( tabIndex : int, out entries : CScriptedFlashArray )
{
	switch( tabIndex )
	{
		case InventoryMenuTab_Potions:
			SortInventoryPotions( entries );
			break;
		default:
			break;
	}
}

function SortInventoryPotions( out entries : CScriptedFlashArray )
{
	var numEntries, eIdx : int;
	var itemEntry : CScriptedFlashObject;
	var oils, bombs, potions, mutagens, others : array< CScriptedFlashObject >;
	
	numEntries = entries.GetLength();
	for( eIdx = 0; eIdx < numEntries; eIdx += 1 )
	{
		itemEntry = entries.GetElementFlashObject( eIdx );
		if ( IsSpecialPotion( itemEntry ) )
		{
			AddItemSorted( others, itemEntry );
		}
		else if ( IsMutagenPotion( itemEntry ) )
		{
			AddItemSorted( mutagens, itemEntry );
		}
		else if ( IsPotion( itemEntry ) )
		{
			AddItemSorted( potions, itemEntry );
		}
		else if ( IsOil( itemEntry ) )
		{
			AddItemSorted( oils, itemEntry );
		}
		else if ( IsBomb( itemEntry ) )
		{
			AddItemSorted( bombs, itemEntry );
		}
		else
		{
			AddItemSorted( others, itemEntry );
		}
	}
	entries.ClearElements();
	
	if ( seIsInventorySortingEnabled() )
	{
		BubbleSort(oils, oils.Size());
		BubbleSort(potions, potions.Size());
		BubbleSort(mutagens, mutagens.Size());
		BubbleSort(others, others.Size());
		BubbleSort(bombs, bombs.Size());
	}
	
	PushBackItems( entries, oils, 0, 0 );
	PushBackItems( entries, potions, 0, 3 );
	PushBackItems( entries, mutagens, potions.Size(), 3 );
	PushBackItems( entries, others, potions.Size() + mutagens.Size(), 3 );
	PushBackItems( entries, bombs, 0, 6 );
}

function IsSpecialPotion( itemEntry : CScriptedFlashObject ) : bool
{
	var category, iconPath : string;

	category = itemEntry.GetMemberFlashString( "category" );
	iconPath = itemEntry.GetMemberFlashString( "iconPath" );
	if ( category == "potion" && ( StrContains( iconPath, "ico_mutagen-potion-20" ) || StrContains( iconPath, "stats_elixir" ) || StrContains( iconPath, "restoring_potion" ) ) )
	{
		return true;
	}
	return false;
}

function IsMutagenPotion( itemEntry : CScriptedFlashObject ) : bool
{
	var category, iconPath : string;

	category = itemEntry.GetMemberFlashString( "category" );
	iconPath = itemEntry.GetMemberFlashString( "iconPath" );
	if ( category == "potion" && StrContains( iconPath, "mutagen_potion" ) )
	{
		return true;
	}
	return false;
}

function IsPotion( itemEntry : CScriptedFlashObject ) : bool
{
	var category : string;

	category = itemEntry.GetMemberFlashString( "category" );
	if ( category == "potion" )
	{
		return true;
	}
	return false;
}

function IsOil( itemEntry : CScriptedFlashObject ) : bool
{
	var category : string;

	category = itemEntry.GetMemberFlashString( "category" );
	if ( category == "oil" )
	{
		return true;
	}
	return false;
}

function IsBomb( itemEntry : CScriptedFlashObject ) : bool
{
	var category : string;

	category = itemEntry.GetMemberFlashString( "category" );
	if ( category == "petard" )
	{
		return true;
	}
	return false;
}

function AddItemSorted( out entries : array< CScriptedFlashObject >, newEntry : CScriptedFlashObject )
{
	var newItemGridPosition, gridPosition : int;
	var numEntries, eIdx : int;
	var itemEntry : CScriptedFlashObject;
	
	newItemGridPosition = newEntry.GetMemberFlashInt( "gridPosition" );
	numEntries = entries.Size();
	for( eIdx = 0; eIdx < numEntries; eIdx += 1 )
	{
		itemEntry = entries[ eIdx ];
		gridPosition = itemEntry.GetMemberFlashInt( "gridPosition" );
		if ( newItemGridPosition < gridPosition )
		{
			entries.Insert( eIdx, newEntry );
			return;
		}
	}
	entries.PushBack( newEntry );
}

function SwapElements(out entries : array< CScriptedFlashObject >, first : int, second : int) 
{
        var tempEntry : CScriptedFlashObject;
		
		tempEntry = entries[first];
		
		entries.Erase( first );
		entries.Insert( first, entries[second] );
		entries.Erase( second );
		entries.Insert( second, tempEntry );
}

function BubbleSort( out entries : array< CScriptedFlashObject >, size : int )
{
	var index_x, index_y : int;
	var itemEntry1, itemEntry2 : CScriptedFlashObject;
	var itemName1, itemName2 : string;
	
	for(  index_x = 0; index_x < size; index_x += 1 ) {
		for( index_y = 0; index_y < size-1; index_y += 1) {
		
			itemEntry1 = entries[index_y];
			itemEntry2 = entries[index_y + 1];
			
			itemName1 = itemEntry1.GetMemberFlashString("itemNameSorter"); // or by "iconPath"
			itemName2 = itemEntry2.GetMemberFlashString("itemNameSorter");
			
			if( StrCmp(itemName1,itemName2) > 0 )
				SwapElements(entries, index_y, index_y + 1);

		}
	}
}

function PushBackItems( out entries : CScriptedFlashArray, newEntries : array< CScriptedFlashObject >, startingPosition : int, offset : int )
{
	var numEntries, eIdx : int;
	var itemEntry : CScriptedFlashObject;
	
	numEntries = newEntries.Size();
	for( eIdx = 0; eIdx < numEntries; eIdx += 1 )
	{
		itemEntry = newEntries[ eIdx ];
		itemEntry.SetMemberFlashInt( "gridPosition", offset + (startingPosition + eIdx) % 3 + ((startingPosition + eIdx) / 3) * 9  );
		entries.PushBackFlashObject( itemEntry );
	}
}
//---=== modPotionsSorting ===---